==> chromium-86.0.4190.0.tar.xz: chromium-86.0.4190.0/chromeos/services/assistant/public/cpp/assistant_prefs.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROMEOS_SERVICES_ASSISTANT_PUBLIC_CPP_ASSISTANT_PREFS_H_
#define CHROMEOS_SERVICES_ASSISTANT_PUBLIC_CPP_ASSISTANT_PREFS_H_

#include <string>

#include "base/component_export.h"

class PrefRegistrySimple;

namespace chromeos {
namespace assistant {
namespace prefs {

// The status of the user's consent. The enum values cannot be changed because
// they are persisted on disk.
enum ConsentStatus {
  // The status is unknown.
  kUnknown = 0,

  // The user accepted activity control access.
  kActivityControlAccepted = 1,

  // The user is not authorized to give consent.
  kUnauthorized = 2,

  // The user's consent information is not found. This is typically the case
  // when consent from the user has never been requested.
  kNotFound = 3,
};

// The mode of the Assistant onboarding experience.
enum class AssistantOnboardingMode {
  kDefault,    // Maps to kAssistantOnboardingModeDefault.
  kEducation,  // Maps to kAssistantOnboardingModeEducation.
  kMaxValue = kEducation
};

// Constants.
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantOnboardingModeDefault[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantOnboardingModeEducation[];

// Preferences.
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantConsentStatus[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantContextEnabled[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantDisabledByPolicy[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantEnabled[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantHotwordAlwaysOn[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantHotwordEnabled[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantLaunchWithMicOpen[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantNotificationEnabled[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantOnboardingMode[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantQuickAnswersEnabled[];

// Registers Assistant specific profile preferences for browser prefs.
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
void RegisterProfilePrefs(PrefRegistrySimple* registry);

// Converts between onboarding mode enum and string representations.
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
AssistantOnboardingMode ToOnboardingMode(const std::string& onboarding_mode);
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
std::string ToOnboardingModeString(AssistantOnboardingMode onboarding_mode);

}  // namespace prefs
}  // namespace assistant
}  // namespace chromeos

#endif  // CHROMEOS_SERVICES_ASSISTANT_PUBLIC_CPP_ASSISTANT_PREFS_H_

==> chromium-88.0.4324.2.tar.xz: chromium-88.0.4324.2/chromeos/services/assistant/public/cpp/assistant_prefs.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROMEOS_SERVICES_ASSISTANT_PUBLIC_CPP_ASSISTANT_PREFS_H_
#define CHROMEOS_SERVICES_ASSISTANT_PUBLIC_CPP_ASSISTANT_PREFS_H_

#include <string>

#include "base/component_export.h"

class PrefRegistrySimple;

namespace chromeos {
namespace assistant {
namespace prefs {

// The status of the user's consent. The enum values cannot be changed because
// they are persisted on disk.
enum ConsentStatus {
  // The status is unknown.
  kUnknown = 0,

  // The user accepted activity control access.
  kActivityControlAccepted = 1,

  // The user is not authorized to give consent.
  kUnauthorized = 2,

  // The user's consent information is not found. This is typically the case
  // when consent from the user has never been requested.
  kNotFound = 3,
};

// The mode of the Assistant onboarding experience.
// This enum is used in histogram, please do not change the values.
enum class AssistantOnboardingMode {
  kDefault = 0,    // Maps to kAssistantOnboardingModeDefault.
  kEducation = 1,  // Maps to kAssistantOnboardingModeEducation.
  kMaxValue = kEducation
};

// Constants.
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantOnboardingModeDefault[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantOnboardingModeEducation[];

// Preferences.
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantConsentStatus[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantContextEnabled[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantDisabledByPolicy[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantEnabled[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantHotwordAlwaysOn[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantHotwordEnabled[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantLaunchWithMicOpen[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantNotificationEnabled[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantOnboardingMode[];
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
extern const char kAssistantQuickAnswersEnabled[];

// Registers Assistant specific profile preferences for browser prefs.
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
void RegisterProfilePrefs(PrefRegistrySimple* registry);

// Converts between onboarding mode enum and string representations.
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
AssistantOnboardingMode ToOnboardingMode(const std::string& onboarding_mode);
COMPONENT_EXPORT(ASSISTANT_SERVICE_PUBLIC)
std::string ToOnboardingModeString(AssistantOnboardingMode onboarding_mode);

}  // namespace prefs
}  // namespace assistant
}  // namespace chromeos

#endif  // CHROMEOS_SERVICES_ASSISTANT_PUBLIC_CPP_ASSISTANT_PREFS_H_
